@@ -8,11 +8,11 @@
 
 #include "emailindexer.h"
 #include "akonadi_indexer_agent_debug.h"
-#include <Collection>
 #include <Akonadi/KMime/MessageFlags>
+#include <Collection>
 
-#include <QTextDocument>
 #include <KEmailAddress>
+#include <QTextDocument>
 
 EmailIndexer::EmailIndexer(const QString &path, const QString &contactDbPath)
     : AbstractIndexer()
@@ -83,8 +83,7 @@ void EmailIndexer::index(const Akonadi::Item &item)
     m_doc->add_value(1, QString::number(item.size()).toStdString());
 
     // Parent collection
-    Q_ASSERT_X(item.parentCollection().isValid(), "Akonadi::Search::EmailIndexer::index",
-               "Item does not have a valid parent collection");
+    Q_ASSERT_X(item.parentCollection().isValid(), "Akonadi::Search::EmailIndexer::index", "Item does not have a valid parent collection");
 
     const Akonadi::Collection::Id colId = item.parentCollection().id();
     const QByteArray term = 'C' + QByteArray::number(colId);
@@ -121,7 +120,8 @@ void EmailIndexer::insert(const QByteArray &key, KMime::Headers::Generics::Addre
     }
 }
 
-namespace {
+namespace
+{
 // Does some extra stuff such as lower casing the email, removing all quotes
 // and removing extra spaces
 // TODO: Move this into KMime?
@@ -141,7 +141,7 @@ void EmailIndexer::insert(const QByteArray &key, const KMime::Types::Mailbox::Li
         return;
     }
     for (const KMime::Types::Mailbox &mbox : list) {
-        const std::string name(mbox.name().toStdString());
+        const auto name(mbox.name().toStdString());
         m_termGen->index_text_without_positions(name, 1, key.data());
         m_termGen->index_text_without_positions(name, 1);
         m_termGen->index_text_without_positions(mbox.address().data(), 1, key.data());
@@ -153,14 +153,15 @@ void EmailIndexer::insert(const QByteArray &key, const KMime::Types::Mailbox::Li
         //
         // Add emails for email auto-completion
         //
-        const QString pa = prettyAddress(mbox);
-        int id = qHash(pa);
+        const auto pa = prettyAddress(mbox);
+        const auto id = qHash(pa);
         try {
-            Xapian::Document doc = m_contactDb->get_document(id);
+            const auto doc = m_contactDb->get_document(id);
+            Q_UNUSED(doc);
             continue;
         } catch (const Xapian::DocNotFoundError &) {
             Xapian::Document doc;
-            const std::string pretty(pa.toStdString());
+            const auto pretty(pa.toStdString());
             doc.set_data(pretty);
 
             Xapian::TermGenerator termGen;
@@ -212,7 +213,7 @@ void EmailIndexer::process(const KMime::Message::Ptr &msg)
     // Process Plain Text Content
     //
 
-    //Index all headers
+    // Index all headers
     m_termGen->index_text_without_positions(std::string(msg->head().constData()), 1, "HE");
 
     KMime::Content *mainBody = msg->mainBodyPart("text/plain");
@@ -341,7 +342,7 @@ void EmailIndexer::remove(const Akonadi::Item &item)
     }
     try {
         m_db->delete_document(item.id());
-        //TODO remove contacts from contact db?
+        // TODO remove contacts from contact db?
     } catch (const Xapian::DocNotFoundError &) {
         return;
     }
